@@ -18,14 +18,14 @@ def _write_analog_f_64(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.float64, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.float64, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -56,14 +56,14 @@ def _write_binary_i_16(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.int16, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.int16, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -80,14 +80,14 @@ def _write_binary_u_16(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint16, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint16, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -104,14 +104,14 @@ def _write_binary_i_32(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.int32, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.int32, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -128,14 +128,14 @@ def _write_binary_u_32(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -152,14 +152,14 @@ def _write_digital_u_8(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint8, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint8, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -176,14 +176,14 @@ def _write_digital_u_16(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint16, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint16, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -200,14 +200,14 @@ def _write_digital_u_32(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -238,14 +238,14 @@ def _write_digital_lines(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=bool, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=bool, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, write_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
 
@@ -253,7 +253,7 @@ def _write_digital_lines(
 def _write_ctr_freq(
         task_handle, freq, duty_cycle, num_samps_per_chan, auto_start, timeout,
         data_layout=FillMode.GROUP_BY_CHANNEL):
-    num_samps_per_chan_written = ctypes.c_int()
+    samps_per_chan_written = ctypes.c_int()
 
     cfunc = lib_importer.windll.DAQmxWriteCtrFreq
     if cfunc.argtypes is None:
@@ -262,17 +262,17 @@ def _write_ctr_freq(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.float64, flags=('C', 'W')),
-                    wrapped_ndpointer(dtype=numpy.float64, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.float64, flags=('C')),
+                    wrapped_ndpointer(dtype=numpy.float64, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, freq, duty_cycle,
-        ctypes.byref(num_samps_per_chan_written), None)
-    check_for_error(error_code)
+        ctypes.byref(samps_per_chan_written), None)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
-    return num_samps_per_chan_written.value
+    return samps_per_chan_written.value
 
 
 def _write_ctr_freq_scalar(task_handle, freq, duty_cycle, auto_start, timeout):
@@ -292,7 +292,7 @@ def _write_ctr_freq_scalar(task_handle, freq, duty_cycle, auto_start, timeout):
 def _write_ctr_time(
         task_handle, high_time, low_time, num_samps_per_chan, auto_start,
         timeout, data_layout=FillMode.GROUP_BY_CHANNEL):
-    num_samps_per_chan_written = ctypes.c_int()
+    samps_per_chan_written = ctypes.c_int()
 
     cfunc = lib_importer.windll.DAQmxWriteCtrTime
     if cfunc.argtypes is None:
@@ -301,17 +301,17 @@ def _write_ctr_time(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.float64, flags=('C', 'W')),
-                    wrapped_ndpointer(dtype=numpy.float64, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.float64, flags=('C')),
+                    wrapped_ndpointer(dtype=numpy.float64, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, high_time, low_time,
-        ctypes.byref(num_samps_per_chan_written), None)
-    check_for_error(error_code)
+        ctypes.byref(samps_per_chan_written), None)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
-    return num_samps_per_chan_written.value
+    return samps_per_chan_written.value
 
 
 def _write_ctr_time_scalar(
@@ -334,7 +334,7 @@ def _write_ctr_time_scalar(
 def _write_ctr_ticks(
         task_handle, high_tick, low_tick, num_samps_per_chan, auto_start,
         timeout, data_layout=FillMode.GROUP_BY_CHANNEL):
-    num_samps_per_chan_written = ctypes.c_int()
+    samps_per_chan_written = ctypes.c_int()
 
     cfunc = lib_importer.windll.DAQmxWriteCtrTicks
     if cfunc.argtypes is None:
@@ -343,17 +343,17 @@ def _write_ctr_ticks(
                 cfunc.argtypes = [
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double, ctypes.c_int,
-                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C', 'W')),
-                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C', 'W')),
+                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C')),
+                    wrapped_ndpointer(dtype=numpy.uint32, flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout,
         data_layout.value, high_tick, low_tick,
-        ctypes.byref(num_samps_per_chan_written), None)
-    check_for_error(error_code)
+        ctypes.byref(samps_per_chan_written), None)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
-    return num_samps_per_chan_written.value
+    return samps_per_chan_written.value
 
 
 def _write_ctr_ticks_scalar(
@@ -383,12 +383,12 @@ def _write_raw(
                     lib_importer.task_handle, ctypes.c_int, c_bool32,
                     ctypes.c_double,
                     wrapped_ndpointer(dtype=numpy_array.dtype,
-                                      flags=('C', 'W')),
+                                      flags=('C')),
                     ctypes.POINTER(ctypes.c_int), ctypes.POINTER(c_bool32)]
 
     error_code = cfunc(
         task_handle, num_samps_per_chan, auto_start, timeout, numpy_array,
         ctypes.byref(samps_per_chan_written), None)
-    check_for_error(error_code)
+    check_for_error(error_code, samps_per_chan_written=samps_per_chan_written.value)
 
     return samps_per_chan_written.value
