@@ -8,9 +8,10 @@ from nidaqmx._task_modules.channels.channel import Channel
 from nidaqmx._task_modules.export_signals import ExportSignals
 from nidaqmx._task_modules.in_stream import InStream
 from nidaqmx._task_modules.read_functions import (
-    _read_analog_f_64, _read_digital_lines, _read_digital_u_32, _read_ctr_freq,
-    _read_ctr_time, _read_ctr_ticks, _read_counter_u_32_ex,
-    _read_counter_f_64_ex)
+    _read_analog_f_64, _read_power_f_64,
+    _read_digital_lines, _read_digital_u_32,
+    _read_ctr_freq,_read_ctr_time, _read_ctr_ticks,
+    _read_counter_u_32_ex, _read_counter_f_64_ex)
 from nidaqmx._task_modules.timing import Timing
 from nidaqmx._task_modules.triggers import Triggers
 from nidaqmx._task_modules.out_stream import OutStream
@@ -30,13 +31,13 @@ from nidaqmx._task_modules.write_functions import (
     _write_analog_f_64, _write_digital_lines, _write_digital_u_32,
     _write_ctr_freq, _write_ctr_time, _write_ctr_ticks)
 from nidaqmx.constants import (
-    AcquisitionType, ChannelType, UsageTypeCI, EveryNSamplesEventType,
+    AcquisitionType, ChannelType, UsageTypeAI, UsageTypeCI, EveryNSamplesEventType,
     READ_ALL_AVAILABLE, UsageTypeCO, _Save)
 from nidaqmx.error_codes import DAQmxErrors
 from nidaqmx.errors import (
     check_for_error, is_string_buffer_too_small, DaqError, DaqResourceWarning)
 from nidaqmx.system.device import Device
-from nidaqmx.types import CtrFreq, CtrTick, CtrTime
+from nidaqmx.types import CtrFreq, CtrTick, CtrTime, PowerMeasurement
 from nidaqmx.utils import unflatten_channel_string, flatten_channel_string
 
 __all__ = ['Task']
@@ -93,7 +94,7 @@ class Task(object):
         self._initialize(self._handle)
 
     def __del__(self):
-        if self._handle is not None:
+        if self._handle:
             warnings.warn(
                 'Task of name "{0}" was not explicitly closed before it was '
                 'destructed. Resources on the task device may still be '
@@ -619,9 +620,23 @@ class Task(object):
 
         # Analog Input
         if read_chan_type == ChannelType.ANALOG_INPUT:
-            data = numpy.zeros(array_shape, dtype=numpy.float64)
-            samples_read = _read_analog_f_64(
-                self._handle, data, number_of_samples_per_channel, timeout)
+            meas_type = channels_to_read.ai_meas_type
+            if meas_type == UsageTypeAI.POWER:
+                voltages = numpy.zeros(array_shape, dtype=numpy.float64)
+                currents = numpy.zeros(array_shape, dtype=numpy.float64)
+
+                samples_read = _read_power_f_64(
+                    self._handle, voltages, currents,
+                    number_of_samples_per_channel, timeout)
+
+                data = []
+                for v, i in zip(voltages, currents):
+                    data.append(PowerMeasurement(voltage=i, current=i))
+
+            else:
+                data = numpy.zeros(array_shape, dtype=numpy.float64)
+                samples_read = _read_analog_f_64(
+                    self._handle, data, number_of_samples_per_channel, timeout)
 
         # Digital Input or Digital Output
         elif (read_chan_type == ChannelType.DIGITAL_INPUT or
@@ -689,7 +704,7 @@ class Task(object):
             raise DaqError(
                 'Read failed, because there are no channels in this task from '
                 'which data can be read.',
-                DAQmxErrors.READ_NO_INPUT_CHANS_IN_TASK.value,
+                DAQmxErrors.READ_NO_INPUT_CHANS_IN_TASK,
                 task_name=self.name)
 
         if (read_chan_type == ChannelType.COUNTER_INPUT and
@@ -704,6 +719,16 @@ class Task(object):
                 return data[:samples_read]
             return data
 
+        if (read_chan_type == ChannelType.ANALOG_INPUT and
+                (meas_type == UsageTypeAI.POWER)):
+
+            if num_samples_not_set and array_shape == 1:
+                return data[0]
+            # Power measurements should not have N channel versions.
+            if samples_read != number_of_samples_per_channel:
+                return data[:samples_read]
+            return data
+
         if num_samples_not_set and array_shape == 1:
             return data.tolist()[0]
 
@@ -1078,7 +1103,7 @@ class Task(object):
             'Number of Lines Per Channel in Task: {0}\n'
             'Number of Lines Per Channel in Data: {1}'
             .format(num_lines_expected, num_lines_in_data),
-            DAQmxErrors.NUM_LINES_MISMATCH_IN_READ_OR_WRITE.value,
+            DAQmxErrors.NUM_LINES_MISMATCH_IN_READ_OR_WRITE,
             task_name=self.name)
 
     def _raise_invalid_write_num_chans_error(
@@ -1093,7 +1118,7 @@ class Task(object):
             'Number of Channels in Task: {0}\n'
             'Number of Channels in Data: {1}'
             .format(number_of_channels, number_of_channels_in_data),
-            DAQmxErrors.WRITE_NUM_CHANS_MISMATCH.value, task_name=self.name)
+            DAQmxErrors.WRITE_NUM_CHANS_MISMATCH, task_name=self.name)
 
     def write(self, data, auto_start=AUTO_START_UNSET, timeout=10.0):
         """
@@ -1233,13 +1258,13 @@ class Task(object):
         elif write_chan_type == ChannelType.DIGITAL_OUTPUT:
             if self.out_stream.do_num_booleans_per_chan == 1:
                 if (not isinstance(element, bool) and
-                        not isinstance(element, bool_)):
+                        not isinstance(element, numpy.bool_)):
                     raise DaqError(
                         'Write failed, because this write method only accepts '
                         'boolean samples when there is one digital line per '
                         'channel in a task.\n\n'
                         'Requested sample type: {0}'.format(type(element)),
-                        DAQmxErrors.UNKNOWN.value, task_name=self.name)
+                        DAQmxErrors.UNKNOWN, task_name=self.name)
 
                 data = numpy.asarray(data, dtype=bool)
                 return _write_digital_lines(
@@ -1253,7 +1278,7 @@ class Task(object):
                         'unsigned 32-bit integer samples when there are '
                         'multiple digital lines per channel in a task.\n\n'
                         'Requested sample type: {0}'.format(type(element)),
-                        DAQmxErrors.UNKNOWN.value, task_name=self.name)
+                        DAQmxErrors.UNKNOWN, task_name=self.name)
 
                 data = numpy.asarray(data, dtype=numpy.uint32)
                 return _write_digital_u_32(
@@ -1312,5 +1337,5 @@ class Task(object):
             raise DaqError(
                 'Write failed, because there are no output channels in this '
                 'task to which data can be written.',
-                DAQmxErrors.WRITE_NO_OUTPUT_CHANS_IN_TASK.value,
+                DAQmxErrors.WRITE_NO_OUTPUT_CHANS_IN_TASK,
                 task_name=self.name)
